from voluptuous import Any

from ._daily_resource import (DailyResourceLocation,
                              DailyTimeSeriesResourceAsset,
                              DailyResourceContours)


class DailyHighTemperature(object):

    @classmethod
    def location(cls, lat, lon, start=None, end=None, unit=None, **kwargs):
        return _DailyHighTemperatureByLocation.find(latitude=lat, longitude=lon,
                                                    start=start, end=end, unit=unit, **kwargs)

    @classmethod
    def asset(cls, asset_uuid, start=None, end=None, unit=None, **kwargs):
        return _DailyHighTemperatureByAsset.find(asset_uuid=asset_uuid, start=start, end=end,
                                                 unit=unit, **kwargs)

    @classmethod
    def contours(cls, asset_uuid, start=None, end=None, unit=None, **kwargs):
        return _DailyHighTemperatureContours.find(asset_uuid=asset_uuid, start=start, end=end,
                                                  unit=unit, **kwargs)


class _DailyHighTemperatureByLocation(DailyResourceLocation):

    _path = '/daily-high-temperature/{latitude}/{longitude}'

    _args = DailyResourceLocation._args.extend({
        'unit': Any('celsius', 'fahrenheit')
    })


class _DailyHighTemperatureByAsset(DailyTimeSeriesResourceAsset):

    _path = '/daily-high-temperature/{asset_uuid}'

    _args = DailyTimeSeriesResourceAsset._args.extend({
        'unit': Any('celsius', 'fahrenheit')
    })


class _DailyHighTemperatureContours(DailyResourceContours):

    _path = '/daily-high-temperature/{asset_uuid}/contours'



from voluptuous import Any

from ._daily_resource import (DailyResourceLocation,
                              DailyAccumulationResourceAsset,
                              DailyResourceContours)


class DailyPrecipitation(object):

    @classmethod
    def location(cls, lat, lon, start=None, end=None, unit=None, **kwargs):
        return _DailyPrecipByLocation.find(latitude=lat, longitude=lon,
                                           start=start, end=end, unit=unit, **kwargs)

    @classmethod
    def asset(cls, asset_uuid, start=None, end=None, unit=None, **kwargs):
        return _DailyPrecipByAsset.find(asset_uuid=asset_uuid, start=start, end=end,
                                        unit=unit, **kwargs)

    @classmethod
    def contours(cls, asset_uuid, start=None, end=None, unit=None, **kwargs):
        return _DailyPrecipContours.find(asset_uuid=asset_uuid, start=start, end=end,
                                         unit=unit, **kwargs)


class _DailyPrecipByLocation(DailyResourceLocation):

    _path = '/daily-precipitation/{latitude}/{longitude}'

    _deserialize = DailyResourceLocation._deserialize.extend({
        'precipitation': float
    })

    _serialize = DailyResourceLocation._serialize.extend({
        'precipitation': float
    })

    _args = DailyResourceLocation._args.extend({
        'unit': Any('inches', 'millimeters')
    })


class _DailyPrecipByAsset(DailyAccumulationResourceAsset):

    _path = '/daily-precipitation/{asset_uuid}'

    _deserialize = DailyAccumulationResourceAsset._deserialize.extend({
        'precipitation': float
    })

    _serialize = DailyAccumulationResourceAsset._serialize.extend({
        'precipitation': float
    })

    _args = DailyAccumulationResourceAsset._args.extend({
        'unit': Any('inches', 'millimeters')
    })


class _DailyPrecipContours(DailyResourceContours):

    _path = '/daily-precipitation/{asset_uuid}/contours'

    _args = DailyResourceContours._args.extend({
        'unit': Any('millimeters', 'inches')
    })



from voluptuous import Any, Schema
from skywiserestclient.validation import (datetime, datetime_to_str, latitude, longitude,
                                          polygon, multipolygon)

from skywiseinsight import InsightResource


class HourlyResource(InsightResource):

    _args = Schema({
        'start': datetime_to_str,
        'end': datetime_to_str
    })

    _deserialize = Schema({
        'startTime': datetime,
        'endTime': datetime,
        'unit': {
            'description': unicode,
            'label': unicode
        }
    }, required=True)

    _serialize = Schema({
        'startTime': datetime_to_str,
        'endTime': datetime_to_str,
        'unit': {
            'description': unicode,
            'label': unicode
        }
    })


class HourlyResourceLocation(HourlyResource):

    _deserialize = HourlyResource._deserialize.extend({
        'latitude': latitude,
        'longitude': longitude,
        'series': [{
            'value': float,
            'validTime': datetime
        }]
    })

    _serialize = HourlyResource._serialize.extend({
        'latitude': latitude,
        'longitude': longitude,
        'series': [{
            'value': float,
            'validTime': datetime_to_str
        }]
    })


class HourlyTimeSeriesResourceAsset(HourlyResource):

    _deserialize = HourlyResource._deserialize.extend({
        'asset': unicode,
        'timeSeriesStatistics': {
            'mean': float,
            'minimum': float,
            'maximum': float
        },
        'series': [{
            'validTime': datetime,
            'value': float,
            'contours': unicode,
            'assetStatistics': {
                'mean': float,
                'minimum': float,
                'maximum': float
            }
        }]
    })

    _serialize = HourlyResource._serialize.extend({
        'asset': unicode,
        'timeSeriesStatistics': {
            'mean': float,
            'minimum': float,
            'maximum': float
        },
        'series': [{
            'validTime': datetime_to_str,
            'value': float,
            'contours': unicode,
            'assetStatistics': {
                'mean': float,
                'minimum': float,
                'maximum': float
            }
        }]
    })


class HourlyAccumulationResourceAsset(HourlyResource):

    _deserialize = HourlyResource._deserialize.extend({
        'asset': unicode,
        'contours': unicode,
        'accumulationStatistics': {
            'mean': float,
            'minimum': float,
            'maximum': float
        },
        'series': [{
            'validTime': datetime,
            'value': float,
            'contours': unicode,
            'assetStatistics': {
                'mean': float,
                'minimum': float,
                'maximum': float
            }
        }]
    })

    _serialize = HourlyResource._serialize.extend({
        'asset': unicode,
        'contours': unicode,
        'accumulationStatistics': {
            'mean': float,
            'minimum': float,
            'maximum': float
        },
        'series': [{
            'validTime': datetime_to_str,
            'value': float,
            'contours': unicode,
            'assetStatistics': {
                'mean': float,
                'minimum': float,
                'maximum': float
            }
        }]
    })


class HourlyResourceContours(HourlyResource):

    _deserialize = HourlyResource._deserialize.extend({
        'asset': unicode,
        'type': unicode,
        'features': [{
            'type': unicode,
            'properties': {
                unicode: float
            },
            'geometry': Any(polygon, multipolygon)
        }]
    })

    _serialize = HourlyResource._serialize.extend({
        'asset': unicode,
        'type': unicode,
        'features': [{
            'type': unicode,
            'properties': {
                unicode: float
            },
            'geometry': Any(polygon, multipolygon)
        }]
    })


class HourlyResourceContourByValidTime(InsightResource):

    _args = Schema({
        'validTime': datetime_to_str
    })

    _deserialize = Schema({
        'validTime': datetime,
        'asset': unicode,
        'type': unicode,
        'features': [{
            'type': unicode,
            'properties': {
                unicode: float
            },
            'geometry': Any(polygon, multipolygon)
        }]
    })

    _serialize = Schema({
        'validTime': datetime_to_str,
        'asset': unicode,
        'type': unicode,
        'features': [{
            'type': unicode,
            'properties': {
                unicode: float
            },
            'geometry': Any(polygon, multipolygon)
        }]
    })



from ._hourly_resource import (HourlyResourceLocation,
                               HourlyTimeSeriesResourceAsset,
                               HourlyResourceContourByValidTime)


class HourlySolarRadiation(object):

    @classmethod
    def location(cls, lat, lon, start=None, end=None, unit=None, **kwargs):
        return _HourlySolarByLocation.find(latitude=lat, longitude=lon,
                                           start=start, end=end, unit=unit, **kwargs)

    @classmethod
    def asset(cls, asset_uuid, start=None, end=None, unit=None, **kwargs):
        return _HourlySolarByAsset.find(asset_uuid=asset_uuid, start=start, end=end,
                                        unit=unit, **kwargs)

    @classmethod
    def contours(cls, asset_uuid, valid_time=None, unit=None, **kwargs):
        return _HourlySolarContours.find(asset_uuid=asset_uuid, validTime=valid_time,
                                         unit=unit, **kwargs)


class _HourlySolarByLocation(HourlyResourceLocation):
    _path = '/hourly-solar-radiation/{latitude}/{longitude}'


class _HourlySolarByAsset(HourlyTimeSeriesResourceAsset):
    _path = '/hourly-solar-radiation/{asset_uuid}'


class _HourlySolarContours(HourlyResourceContourByValidTime):
    _path = '/hourly-solar-radiation/{asset_uuid}/contours'



from voluptuous import Any

from ._daily_resource import (DailyResourceLocation,
                              DailyTimeSeriesResourceAsset,
                              DailyResourceContourByValidDate)


class DailyEtTallCrop(object):

    @classmethod
    def location(cls, lat, lon, start=None, end=None, unit=None, **kwargs):
        return _DailyEtTallCropByLocation.find(latitude=lat, longitude=lon,
                                               start=start, end=end, unit=unit,
                                               **kwargs)

    @classmethod
    def asset(cls, asset_uuid, start=None, end=None, unit=None, **kwargs):
        return _DailyEtTallCropByAsset.find(asset_uuid=asset_uuid, start=start,
                                            end=end, unit=unit, **kwargs)

    @classmethod
    def contours(cls, asset_uuid, validDate=None, unit=None, **kwargs):
        return _DailyEtTallCropContours.find(asset_uuid=asset_uuid, validDate=validDate,
                                             unit=unit, **kwargs)


class _DailyEtTallCropByLocation(DailyResourceLocation):

    _path = '/daily-evapotranspiration-tall-crop/{latitude}/{longitude}'

    _args = DailyResourceLocation._args.extend({
        'unit': Any('inches', 'millimeters')
    })


class _DailyEtTallCropByAsset(DailyTimeSeriesResourceAsset):

    _path = '/daily-evapotranspiration-tall-crop/{asset_uuid}'

    _args = DailyTimeSeriesResourceAsset._args.extend({
        'unit': Any('inches', 'millimeters')
    })


class _DailyEtTallCropContours(DailyResourceContourByValidDate):

    _path = '/daily-evapotranspiration-tall-crop/{asset_uuid}/contours'

    _args = DailyResourceContourByValidDate._args.extend({
        'unit': Any('millimeters', 'inches')
    })



import os
from skywiserestclient import SkyWiseJSON, SkyWiseResource


class InsightResource(SkyWiseJSON, SkyWiseResource):
    pass

_site = os.getenv('PSW_INSIGHT_SITE', 'http://insight.api.wdtinc.com')
_user = os.getenv('PSW_INSIGHT_USER', '')
_password = os.getenv('PSW_INSIGHT_PASSWORD', '')

InsightResource.set_site(_site)
InsightResource.set_user(_user)
InsightResource.set_password(_password)

from skywiseinsight.cdd import Cdd
from skywiseinsight.gdd import Gdd
from skywiseinsight.hdd import Hdd
from skywiseinsight.daily_low_temperature import DailyLowTemperature
from skywiseinsight.daily_high_temperature import DailyHighTemperature
from skywiseinsight.daily_precipitation import DailyPrecipitation
from skywiseinsight.hourly_precipitation import HourlyPrecipitation
from skywiseinsight.daily_solar_radiation import DailySolarRadiation
from skywiseinsight.hourly_solar_radiation import HourlySolarRadiation
from skywiseinsight.hourly_temperature import HourlyTemperature
from skywiseinsight.hourly_dewpoint import HourlyDewpoint
from skywiseinsight.hourly_wind_speed import HourlyWindSpeed
from skywiseinsight.hourly_wind_direction import HourlyWindDirection
from skywiseinsight.hourly_relative_humidity import HourlyRelativeHumidity
from skywiseinsight.daily_et_short_crop import DailyEtShortCrop
from skywiseinsight.daily_et_tall_crop import DailyEtTallCrop
from skywiseinsight.hourly_et_short_crop import HourlyEtShortCrop
from skywiseinsight.hourly_et_tall_crop import HourlyEtTallCrop
from skywiseinsight.asset import Asset



#!/usr/bin/env python
from setuptools import setup

setup(
    name='skywise-insight',
    version='1.0.0',
    package_data={'': ['README.md']},
    packages=['skywiseinsight'],
    install_requires=[
        'skywise-rest-client==1.0.0',
        'voluptuous==0.8.8'
    ],

    # metadata for upload to PyPI
    author='Weather Decision Technologies',
    author_email='jstewart@wdtinc.com',
    description='SkyWise Insight API Python Client Library',
    url='https://github.com/wdtinc/skywise-insight-py',
    zip_safe=False,
    classifiers=(
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
    )
)
